@@ -161,13 +161,17 @@ fn main() {
             // this is generated by cmake, mainly to check compat with intrinsics
             // but we use the older asm versions anyway
             std::fs::write(config_dir.join("neon-compat.h"), r#"
-                /* Define compiler-independent count-leading-zeros macros */
+                /* Define compiler-independent count-leading-zeros and byte-swap macros */
                 #if defined(_MSC_VER) && !defined(__clang__)
                 #define BUILTIN_CLZ(x)  _CountLeadingZeros(x)
                 #define BUILTIN_CLZLL(x)  _CountLeadingZeros64(x)
+                #define BUILTIN_BSWAP32(x)  _byteswap_ulong(x)
+                #define BUILTIN_BSWAP64(x)  _byteswap_uint64(x)
                 #elif defined(__clang__) || defined(__GNUC__)
                 #define BUILTIN_CLZ(x)  __builtin_clz(x)
                 #define BUILTIN_CLZLL(x)  __builtin_clzll(x)
+                #define BUILTIN_BSWAP32(x)  __builtin_bswap32(x)
+                #define BUILTIN_BSWAP64(x)  __builtin_bswap64(x)
                 #else
                 #error "Unknown compiler"
                 #endif
@@ -200,6 +204,8 @@ fn main() {
                     c.file("vendor/simd/powerpc/jsimd.c");
                 },
                 "arm" => {
+                    c.file("vendor/simd/arm/aarch32/jchuff-neon.c");
+                    c.file("vendor/simd/arm/jdcolor-neon.c");
                     c.file("vendor/simd/arm/jfdctint-neon.c");
                     c.file("vendor/simd/arm/aarch32/jsimd.c");
                 },
